/* Atomix -- a little mind game about atoms and molecules.
 * Copyright (C) 1999 Jens Finke
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _ATOMIX_PLAY_FIELD_H 
#define _ATOMIX_PLAY_FIELD_H 

#include <gnome.h>
#include <tree.h>
#include "global.h"
#include "atomix_object.h"

typedef struct _PlayField  PlayField;


struct _PlayField
{
    guint n_rows;
    guint n_cols;
    gint selector_row; /* currently not used */
    gint selector_col; /* currently not used */
    AtomixObject* matrix[MAX_ROWS][MAX_COLS];
};


PlayField*
playfield_new(void);

void
playfield_destroy(PlayField* m);

gboolean
playfield_add_row(PlayField* pf);

gboolean
playfield_add_column(PlayField* pf);

AtomixObject*
playfield_get_object(PlayField *pf, guint row, guint col);

void
playfield_set_object(PlayField* pf, AtomixObject* obj, guint row, guint col);

void
playfield_set_type(PlayField* pf, AtomixType type, guint row, guint col);

AtomixType
playfield_get_type(PlayField* pf, guint row, guint col);

void
playfield_create_border(PlayField* pf);

PlayField*
playfield_copy(PlayField* pf);

void
playfield_set_selector(PlayField* pf, guint row, guint col);

void
playfield_get_selector(PlayField* pf, gint* row, gint* col);

AtomixObject*
playfield_clear_tile(PlayField* pf, guint row, guint col);

void
playfield_swap_tiles(PlayField* pf, guint src_row, guint src_col,
		     guint dest_row, guint dest_col);

void
playfield_print(PlayField* pf);

PlayField* 
playfield_load_xml(xmlNodePtr pf_node);

void 
playfield_save_xml(PlayField *pf, xmlNodePtr pf_node);


#endif /* _ATOMIX_PLAY_FIELD_H */
