/* Atomix -- a little mind game about atoms and molecules.
 * Copyright (C) 1999 Jens Finke
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _ATOMIX_THEME_H_
#define _ATOMIX_THEME_H_

#include <gnome.h>
#include "global.h"

typedef struct _Theme     Theme;

/**
 * Theme structure.
 */
struct _Theme 
{
    gchar* name;            /* name of the theme */
    gchar* path;            /* full qualified path to the theme directory */
    GPtrArray* obstacles;   /* list of obstacle images */
    GPtrArray* moveables;   /* list of moveable images */
    GPtrArray* decor;       /* list of decor images */

    gint tile_width;        /* width of each tile */
    gint tile_height;       /* height of each tile */
    gint animstep;          /* number of pixels to move a atom in one 
			       animation step */
    gchar* bgcolor;         /* X description of the background color */
    gchar* bgoutline;       /* X description of the outline color of the
			       background. */
}; 

/**
 * Theme file structure:
 *
 * theme "<name>" 
 * {
 *   OBSTACLE = {
 *    [<nr> =] <img_name>.{png|xpm|gif|jpg},
 *    ...
 *   }
 * 
 *   MOVEABLE = {
 *    [<nr> =] <img_name>.{png|xpm|gif|jpg},
 *    ...
 *   }
 *
 *   DECOR = {
 *    [<nr> =] <img_name>.{png|xpm|gif|jpg},
 *    ...
 *   }
 * }
 *
 * Where <nr> are ordered rising natural numbers. Though the numbers have
 * only the effect of better readabilty, because the position of the image 
 * will be implicit determines the number. For each block [OBSTACLE|MOVEABLE|DECOR]
 * the numbers starts with 0.
 */

typedef enum {
  THEME_TOKEN_INVALID = G_TOKEN_LAST,
  THEME_TOKEN_THEME,
  THEME_TOKEN_MOVEABLE,
  THEME_TOKEN_OBSTACLE,
  THEME_TOKEN_DECOR
} ThemeTokenType;

typedef enum {
  THEME_NONE_READ, 
  THEME_THEME_READ,
  THEME_IDENTIFIER_READ,
  THEME_OPEN_BRACE,
  THEME_CONTENT,
  THEME_CLOSED_BRACE,
  THEME_EQUAL_READ,
  THEME_NUMBER_READ,
  THEME_NUMBER_EQUAL_READ,
  THEME_IMAGE_READ
} ThemeFSM;

GHashTable* available_themes;

Theme*
theme_new(void);

void
theme_destroy(Theme* theme);

void
theme_add_object_image(Theme* theme, AtomixType type, gchar* file);

gchar*
theme_get_object_image(Theme* theme, AtomixType type, guint id);

void
theme_set_path(Theme* theme, gchar* path);

Theme*
theme_load(char* name, LoadResult* result);

Theme*
theme_load_xml(char* name, LoadResult* result);

void
theme_save_xml(Theme *theme, gchar *filename);

void
theme_create_hash_table(void);

void
theme_destroy_hash_table(void);

void
theme_tile_size(Theme *theme, gint *width, gint *height);

#endif /* _ATOMIX_THEME_H_ */
